<?php

/**
 * @file
 * Views access plugin handler for grant access only for 1Pass servers.
 */

/**
 * Class OnepassAccessPlugin restricted for access from OnePass servers only.
 */
class OnepassAccessPlugin extends views_plugin_access {

  /**
   * Return a string to display as the clickable title for the access control.
   */
  public function summary_title() {
    return t('OnePass access plugin');
  }

  /**
   * Determine if the current user has access or not.
   */
  public function access($account) {
    return onepass_authenticate($account);
  }

  /**
   * Determine the access callback and arguments.
   *
   * This information will be embedded in the menu in order to reduce
   * performance hits during menu item access testing, which happens a lot.
   *
   * @return mixed
   *   An array; the first item should be the function to call,
   *   and the second item should be an array of arguments. The first
   *   item may also be TRUE (bool only) which will indicate no
   *   access control.)
   */
  public function get_access_callback() {
    return array('onepass_authenticate', array());
  }

}
